==> gitlab_16.11.6.orig.tar.bz2: gitlab-foss-v16.11.6/spec/services/lfs/lock_file_service_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Lfs::LockFileService, feature_category: :source_code_management do
  let(:project)      { create(:project) }
  let(:current_user) { create(:user) }

  subject { described_class.new(project, current_user, params) }

  describe '#execute' do
    let(:params) { { path: 'README.md' } }

    context 'when not authorized' do
      it "doesn't succeed" do
        result = subject.execute

        expect(result[:status]).to eq(:error)
        expect(result[:http_status]).to eq(403)
        expect(result[:message]).to eq('You have no permissions')
      end
    end

    context 'when authorized' do
      before do
        project.add_developer(current_user)
      end

      context 'with an existent lock' do
        let!(:lock) { create(:lfs_file_lock, project: project) }

        it "doesn't succeed" do
          expect(subject.execute[:status]).to eq(:error)
        end

        it "doesn't create the Lock" do
          expect do
            subject.execute
          end.not_to change { LfsFileLock.count }
        end
      end

      context 'without an existent lock' do
        it "succeeds" do
          expect(subject.execute[:status]).to eq(:success)
        end

        it "creates the Lock" do
          expect do
            subject.execute
          end.to change { LfsFileLock.count }.by(1)
        end
      end

      context 'when an error is raised' do
        it "doesn't succeed" do
          allow_next_instance_of(described_class) do |instance|
            allow(instance).to receive(:create_lock!).and_raise(StandardError)
          end

          expect(subject.execute[:status]).to eq(:error)
        end
      end
    end
  end
end

==> gitlab_17.6.5.orig.tar.bz2: gitlab-foss-v17.6.5/spec/services/lfs/lock_file_service_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Lfs::LockFileService, feature_category: :source_code_management do
  let(:project)      { create(:project) }
  let(:current_user) { create(:user) }

  describe '#execute' do
    subject(:execute) { described_class.new(project, current_user, params).execute }

    let(:params) { { path: 'README.md' } }

    context 'when not authorized' do
      it "doesn't succeed" do
        result = execute

        expect(result[:status]).to eq(:error)
        expect(result[:http_status]).to eq(403)
        expect(result[:message]).to eq('You have no permissions')
      end

      it_behaves_like 'does not refresh project.lfs_file_locks_changed_epoch'
    end

    context 'when authorized' do
      before do
        project.add_developer(current_user)
      end

      context 'with an existent lock' do
        let!(:lock) { create(:lfs_file_lock, project: project) }

        it "doesn't succeed" do
          expect(execute[:status]).to eq(:error)
        end

        it "doesn't create the Lock" do
          expect { execute }.not_to change { LfsFileLock.count }
        end

        it_behaves_like 'does not refresh project.lfs_file_locks_changed_epoch'
      end

      context 'without an existent lock' do
        it "succeeds" do
          expect(execute[:status]).to eq(:success)
        end

        it "creates the Lock" do
          expect { execute }.to change { LfsFileLock.count }.by(1)
        end

        it_behaves_like 'refreshes project.lfs_file_locks_changed_epoch value'
      end

      context 'when an error is raised' do
        before do
          allow_next_instance_of(described_class) do |instance|
            allow(instance).to receive(:create_lock!).and_raise(StandardError)
          end
        end

        it "doesn't succeed" do
          expect(execute[:status]).to eq(:error)
        end

        it_behaves_like 'does not refresh project.lfs_file_locks_changed_epoch'
      end
    end
  end
end
